netapp_ontap.models.consistency_group_igroup API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_igroup`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupIgroupSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupIgroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET POST PATCH`

    A comment available for use by the administrator. Valid in POST and PATCH.

  `igroups: List[ConsistencyGroupChildLunsLunMapsIgroupIgroups] GET POST PATCH`

    The existing initiator groups that are members of the group. Optional in POST.
    This property is mutually exclusive with the initiators property during POST.
    This array contains only the direct children of the initiator group. If the member initiator groups have further nested initiator groups, those are reported in the `igroups` property of the child initiator group.
    Zero or more nested initiator groups can be supplied when the initiator group is created. The initiator group will act as if it contains the aggregation of all initiators in any nested initiator groups.
    After creation, nested initiator groups can be added or removed from the initiator group using the `/protocols/san/igroups/{igroup.uuid}/igroups` endpoint. See `POST /protocols/san/igroups/{igroup.uuid}/igroups` and `DELETE /protocols/san/igroups/{igroup.uuid}/igroups/{uuid}` for more details.

  `initiators: List[ConsistencyGroupChildLunsLunMapsIgroupInitiators] GET POST PATCH`

    The initiators that are members of the group.

  `name: str GET POST PATCH`

    The name of the initiator group. Required in POST; optional in PATCH.

    Example: igroup1

  `os_type: str GET POST PATCH`

    The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system. Required in POST; optional in PATCH.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - vmware
    - windows
    - xen
  `protocol: str GET POST`

    The protocols supported by the initiator group. This restricts the type of initiators that can be added to the initiator group. Optional in POST; if not supplied, this defaults to mixed.
    The protocol of an initiator group cannot be changed after creation of the group.

    Valid choices:

    - fcp
    - iscsi
    - mixed
  `uuid: str GET`

    The unique identifier of the initiator group.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412